StmFlashSize

Struct StmFlashSize 

pub struct StmFlashSize { /* private fields */ }
STM Flash Size Register

This is a 16-bit value that indicates the size of the flash memory in kilobytes.

Implementations

Source

impl StmFlashSize

pub const STM32F4_ADDRESS_OF_U16: u32 = 0x1FFF_7A20

Address containing the 16-bit flash size value. The flash size is the upper 16 bits of this value, so stored at 0x1FFF_7A22. We store a 4-bit aligned address.

pub const STM32F1_ADDRESS_OF_U16: u32 = 0x1FFF_F7E0

pub fn addr_from_family(family: StmFamily) -> Option<u32>

Get the initial address for reading the Flash Size based on the STM32 family.

pub fn new(raw: u16) -> Self

Create new Flash Size from raw 16-bit value

pub fn raw(&self) -> u16

Get raw Flash Size value

pub fn size_bytes(&self) -> u32

Get Flash size in bytes

pub fn size_kb(&self) -> u32

Get Flash size in KB